@@ -31,7 +31,10 @@ rm tt
 
 #Lets shuffle the input to distribute it better
 
-cat coord.txt | shuf | xargs -I {} -n 1 bash -c 'echo -e "samtools mpileup -DguS -f $1 -r {} -b bamlist.txt | bcftools view -bvcg - > tmpbcf/tmp.{}.bcf && bcftools view tmpbcf/tmp.{}.bcf > tmpbcf/tmp.{}.vcf\n"'
+# cat coord.txt | shuf | xargs -I {} -n 1 bash -c 'echo -e "samtools mpileup -DguS -f $1 -r {} -b bamlist.txt | bcftools view -bvcg - > tmpbcf/tmp.{}.bcf && bcftools view tmpbcf/tmp.{}.bcf > tmpbcf/tmp.{}.vcf\n"'
+
+#Getting rid of having a bcftools view on each chromosome - save it for the end
+cat coord.txt | shuf | xargs -I {} -n 1 bash -c 'echo -e "samtools mpileup -DguS -f $1 -r {} -b bamlist.txt | bcftools view -bvcg - > tmpbcf/tmp.{}.bcf\n"'
 
 #Wait for these to finish
 echo -e "wait\n" 
